Channel

Struct Channel 

pub struct Channel<T, S: SwapSlot<T>> { /* private fields */ }

Implementations

Source

impl<T, S: SwapSlot<T>> Channel<T, S>

pub fn broadcast(&self, object: T) -> Result<(), SendError<T>>

Publishes values to the circular buffer at wi % size

Arguments
  • object - owned object to be published
pub fn try_recv( &self, ri: &AtomicCounter, skip_items: usize, ) -> Result<Arc<T>, TryRecvError>

Receives some atomic reference to an object if queue is not empty, or None if it is. Never Blocks

pub fn close(&self)

Closes the channel

pub fn len(&self) -> usize

Returns the length of the queue

pub fn is_empty(&self) -> bool

Checks if nothings has been published yet

pub fn inc_sub_count(&self)

Increment the number of subs

pub fn dec_sub_count(&self)

Decrement the number of subs