pub struct Channel<T, S: SwapSlot<T>> { /* private fields */ }Implementations
Sourceimpl<T, S: SwapSlot<T>> Channel<T, S>
impl<T, S: SwapSlot<T>> Channel<T, S>
Sourcepub fn broadcast(&self, object: T) -> Result<(), SendError<T>>
pub fn broadcast(&self, object: T) -> Result<(), SendError<T>>
Publishes values to the circular buffer at wi % size
Arguments
object- owned object to be published
Sourcepub fn try_recv(
&self,
ri: &AtomicCounter,
skip_items: usize,
) -> Result<Arc<T>, TryRecvError>
pub fn try_recv( &self, ri: &AtomicCounter, skip_items: usize, ) -> Result<Arc<T>, TryRecvError>
Receives some atomic reference to an object if queue is not empty, or None if it is. Never Blocks
Sourcepub fn inc_sub_count(&self)
pub fn inc_sub_count(&self)
Increment the number of subs
Sourcepub fn dec_sub_count(&self)
pub fn dec_sub_count(&self)
Decrement the number of subs